## Ansættelseskontrakt

Mellem undertegnede

<company-name>Smagskassen A/S  
Industriparken 48, st., 6854 Henne  
CVR-nr.: 43215678</company-name>

og

## Asma Raza  
Baggesensvej 7, 2. tv., 6330 Padborg

indgås følgende aftale:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Ansættelsen begynder den 15.07.2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Arbejdsstedet er Industriparken 48, st., 2600 Glostrup.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Stillingen er som lager- og logistikmedarbejder.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderen skal primært varetage følgende opgaver:

- Plukning og pakning af varer  
- Modtagelse af varer  
- Lagerstyring  
- Truckkørsel  
- Daglig opfyldning af lager

Virksomheden kan tilpasse og udvide arbejdsopgaverne efter virksomhedens behov.

<trial-period>
Der er ikke aftalt nogen prøvetid.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige bruttoløn udgør kr. 372.000 (før skat, pension og lovpligtige bidrag). Lønnen udbetales bagud per måned med kr. 31.000 og indsættes på medarbejderens anviste konto den sidste hverdag i måneden.  

Lønnen tages op til revision én gang årligt.
</salary>

<pension>
## [SECTION-IDX]. Pension

Der etableres pensionsordning i Industriens Pension. Virksomheden indbetaler 8% og medarbejderen 4% af alle faste løndele som pensionsbidrag.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag, herunder ATP, barselsfonden samt øvrige relevante bidrag i overensstemmelse med gældende dansk lovgivning.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid udgør 37 timer, eksklusive frokostpause. Arbejdstiden placeres indenfor virksomhedens gældende arbejdstidsrammer.  
Der er ved lønfastsættelsen taget højde for eventuel overarbejde, som afregnes efter overenskomstens bestemmelser.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen optjener og afholder ferie efter reglerne i ferieloven. Der ydes ferie med løn. Det særlige ferietillæg i henhold til ferieloven udbetales med 1%.  
Juleaftensdag og Nytårsaftensdag er fridage med fuld løn.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Der ydes ikke ekstra feriefridage udover ferielovens bestemmelser.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til relevant efter- og videreuddannelse i overensstemmelse med virksomhedens behov og gældende regler i overenskomsten. Efteruddannelse aftales løbende mellem <company-name>Smagskassen A/S</company-name> og medarbejderen.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal medarbejderen så hurtigt som muligt give <company-name>Smagskassen A/S</company-name> besked om fraværet.  
Virksomheden kan forlange lægeerklæring efter 3 dages fravær; udgiften hertil betales af virksomheden.  
Medarbejderen har ret til fuld løn under sygdom.  
Der gives 2 dages frihed med løn ved barns sygdom pr. kalenderår.  
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel og forældreorlov

Ved graviditet eller barsel/adoption gælder følgende:

- Mor: Ret til orlov med fuld løn i 4 uger før fødslen samt 14 uger efter fødslen.
- Far/medmor: Ret til 2 ugers orlov med fuld løn efter fødslen.

Rettighederne følger i øvrigt de gældende regler i barselsloven og i overenskomsten.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan af begge parter opsiges med 14 dages varsel til udgangen af en uge, medmindre overenskomsten eller lovgivningen bestemmer andet.  
Opsigelsen skal være skriftlig og meddeles modtageren rettidigt.

Alle øvrige opsigelsesvarsler følger reglerne i Industriens Overenskomst (DI/CO-industri) samt gældende dansk lovgivning.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af Industriens Overenskomst (DI/CO-industri).
</collective-agreement>

## [SECTION-IDX]. Fortrolighed

Medarbejderen pålægges tavshedspligt både under og efter ansættelsen, hvad angår alle oplysninger om <company-name>Smagskassen A/S</company-name>s forretningsforhold, samarbejdspartnere, arbejdsprocesser og andet, som ikke er offentligt tilgængeligt. Videregivelse til uvedkommende må ikke finde sted, og lov om forretningshemmeligheder skal overholdes.

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet er omfattet af dansk ret. I det omfang denne kontrakt ikke stiller medarbejderen bedre, finder funktionær- og ferielovene samt Industriens Overenskomst (DI/CO-industri) anvendelse.

Glostrup, den 23.06.2024

Medarbejderen _________________________________

Virksomheden  _________________________________